@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client;
 # ABSTRACT: A comprehensive, DWIM-featured client to the MetaCPAN API
-$MetaCPAN::Client::VERSION = '2.012000';
+$MetaCPAN::Client::VERSION = '2.013000';
 use Moo;
 use Carp;
 use Ref::Util qw< is_arrayref is_hashref >;
@@ -19,6 +19,7 @@ use MetaCPAN::Client::Pod;
 use MetaCPAN::Client::Rating;
 use MetaCPAN::Client::Release;
 use MetaCPAN::Client::Mirror;
+use MetaCPAN::Client::Package;
 use MetaCPAN::Client::Permission;
 use MetaCPAN::Client::ResultSet;
 
@@ -75,6 +76,14 @@ sub file {
     return $self->_get_or_search( 'file', $arg, $params );
 }
 
+sub package {
+    my $self   = shift;
+    my $arg    = shift;
+    my $params = shift;
+
+    return $self->_get_or_search( 'packages', $arg, $params );
+}
+
 sub permission {
     my $self   = shift;
     my $arg    = shift;
@@ -225,6 +234,7 @@ sub _get {
         or croak sprintf( 'Failed to fetch %s (%s)', ucfirst($type), $arg );
 
     $type = 'DownloadURL' if $type eq 'download_url';
+    $type = 'Package'     if $type eq 'packages';
 
     my $class = 'MetaCPAN::Client::' . ucfirst($type);
     return $class->new_from_request($response, $self);
@@ -381,7 +391,7 @@ MetaCPAN::Client - A comprehensive, DWIM-featured client to the MetaCPAN API
 
 =head1 VERSION
 
-version 2.012000
+version 2.013000
 
 =head1 SYNOPSIS
 
@@ -517,6 +527,12 @@ L<MetaCPAN::Client::Release> objects on a complex (L<search spec based|/"SEARCH
 
 Returns a L<MetaCPAN::Client::Mirror> object.
 
+=head2 package
+
+    my $package = $mcpan->package('MooseX::Types');
+
+Returns a L<MetaCPAN::Client::Package> object.
+
 =head2 permission
 
     my $permission = $mcpan->permission('MooseX::Types');
