@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client::Module;
 # ABSTRACT: A Module data object
-$MetaCPAN::Client::Module::VERSION = '2.012000';
+$MetaCPAN::Client::Module::VERSION = '2.013000';
 use Moo;
 extends 'MetaCPAN::Client::File';
 
@@ -12,6 +12,11 @@ sub metacpan_url {
             $self->author, $self->release, $self->path );
 }
 
+sub package {
+    my $self = shift;
+    return $self->client->package( $self->documentation );
+}
+
 sub permission {
     my $self = shift;
     return $self->client->permission( $self->documentation );
@@ -31,7 +36,7 @@ MetaCPAN::Client::Module - A Module data object
 
 =head1 VERSION
 
-version 2.012000
+version 2.013000
 
 =head1 SYNOPSIS
 
@@ -53,6 +58,10 @@ Whatever L<MetaCPAN::Client::File> has.
 
 Returns a link to the module page on MetaCPAN.
 
+=head2 package
+
+Returns an L<MetaCPAN::Client::Package> object for the module.
+
 =head2 permission
 
 Returns an L<MetaCPAN::Client::Permission> object for the module.
